==> jc-1.4.0.tar.gz: jas/LocalVarEntry.h <==
// public class jas.LocalVarEntry

// class file dependencies
// @dep_class 278f7903dc9329e1 jas_LocalVarEntry
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_jas_LocalVarEntry_H_
#define _JC_jas_LocalVarEntry_H_

// Forward structure declarations
struct _jc_jas_CP$object;
struct _jc_jas_ClassEnv$object;
struct _jc_jas_CodeAttr$object;
struct _jc_jas_Label$object;
struct _jc_java_io_DataOutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_jas_LocalVarEntry$sub_refs	_jc_jas_LocalVarEntry$sub_refs;
typedef struct _jc_jas_LocalVarEntry$sub_nonrefs	_jc_jas_LocalVarEntry$sub_nonrefs;
typedef struct _jc_jas_LocalVarEntry$refs	_jc_jas_LocalVarEntry$refs;
typedef struct _jc_jas_LocalVarEntry$nonrefs	_jc_jas_LocalVarEntry$nonrefs;
typedef struct _jc_jas_LocalVarEntry$object	_jc_jas_LocalVarEntry$object;

typedef const struct _jc_jas_LocalVarEntry$vmethods	_jc_jas_LocalVarEntry$vmethods;
typedef const struct _jc_jas_LocalVarEntry$vtable	_jc_jas_LocalVarEntry$vtable;
typedef const struct _jc_jas_LocalVarEntry$vtype	_jc_jas_LocalVarEntry$vtype;

// Constructors
extern void _jc_jas_LocalVarEntry$method$_init$babd757df4230a42(_jc_env *, struct _jc_jas_LocalVarEntry$object *, struct _jc_jas_Label$object *, struct _jc_jas_Label$object *, struct _jc_jas_CP$object *, struct _jc_jas_CP$object *, jint);
extern void _jc_jas_LocalVarEntry$method$_init$300984af1e9ff307(_jc_env *, struct _jc_jas_LocalVarEntry$object *, struct _jc_jas_Label$object *, struct _jc_jas_Label$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, jint);

// Virtual methods
extern void _jc_jas_LocalVarEntry$method$resolve$f7bbca8128967cc2(_jc_env *, struct _jc_jas_LocalVarEntry$object *, struct _jc_jas_ClassEnv$object *);
extern void _jc_jas_LocalVarEntry$method$write$d61e8c36d8c1cacd(_jc_env *, struct _jc_jas_LocalVarEntry$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *);

// Virtual method descriptors
extern _jc_method _jc_jas_LocalVarEntry$method_info$resolve$f7bbca8128967cc2;
extern _jc_method _jc_jas_LocalVarEntry$method_info$write$d61e8c36d8c1cacd;

// Virtual methods structure
struct _jc_jas_LocalVarEntry$vmethods {
	void	(*resolve$f7bbca8128967cc2)(_jc_env *, struct _jc_jas_LocalVarEntry$object *, struct _jc_jas_ClassEnv$object *);
	void	(*write$d61e8c36d8c1cacd)(_jc_env *, struct _jc_jas_LocalVarEntry$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *);
};

// Vtable
struct _jc_jas_LocalVarEntry$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_LocalVarEntry$vmethods	jas_LocalVarEntry;
};

// Vtype
struct _jc_jas_LocalVarEntry$vtype {
	_jc_type			type;
	_jc_jas_LocalVarEntry$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_LocalVarEntry$sub_refs {
	struct _jc_jas_Label$object	*start;
	struct _jc_jas_Label$object	*end;
	struct _jc_jas_CP$object	*name;
	struct _jc_jas_CP$object	*sig;
};

// Reference instance fields (object)
struct _jc_jas_LocalVarEntry$refs {
    _jc_jas_LocalVarEntry$sub_refs	jas_LocalVarEntry;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_LocalVarEntry$sub_nonrefs {
	jint	slot;
};

// Non-reference instance fields (object)
struct _jc_jas_LocalVarEntry$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_LocalVarEntry$sub_nonrefs	jas_LocalVarEntry;
};

// Object instance structure
struct _jc_jas_LocalVarEntry$object {
	_jc_jas_LocalVarEntry$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_LocalVarEntry$vtype	*vtype;
	_jc_jas_LocalVarEntry$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_LocalVarEntry$vtype _jc_jas_LocalVarEntry$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_LocalVarEntry, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_LocalVarEntry$class_object;

#endif	/* _JC_jas_LocalVarEntry_H_ */

==> jc-1.4.6.tar.gz: jas/LocalVarEntry.h <==
// public class jas.LocalVarEntry

// class file dependencies
// @dep_class 278f7903dc9329e1 jas_LocalVarEntry
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_jas_LocalVarEntry_H_
#define _JC_jas_LocalVarEntry_H_

// Forward structure declarations
struct _jc_jas_CP$object;
struct _jc_jas_ClassEnv$object;
struct _jc_jas_CodeAttr$object;
struct _jc_jas_Label$object;
struct _jc_java_io_DataOutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_jas_LocalVarEntry$sub_refs	_jc_jas_LocalVarEntry$sub_refs;
typedef struct _jc_jas_LocalVarEntry$sub_nonrefs	_jc_jas_LocalVarEntry$sub_nonrefs;
typedef struct _jc_jas_LocalVarEntry$refs	_jc_jas_LocalVarEntry$refs;
typedef struct _jc_jas_LocalVarEntry$nonrefs	_jc_jas_LocalVarEntry$nonrefs;
typedef struct _jc_jas_LocalVarEntry$object	_jc_jas_LocalVarEntry$object;

typedef const struct _jc_jas_LocalVarEntry$vmethods	_jc_jas_LocalVarEntry$vmethods;
typedef const struct _jc_jas_LocalVarEntry$vtable	_jc_jas_LocalVarEntry$vtable;
typedef const struct _jc_jas_LocalVarEntry$vtype	_jc_jas_LocalVarEntry$vtype;

// Constructors
extern void _jc_jas_LocalVarEntry$method$_init$babd757df4230a42(_jc_env *, struct _jc_jas_LocalVarEntry$object *, struct _jc_jas_Label$object *, struct _jc_jas_Label$object *, struct _jc_jas_CP$object *, struct _jc_jas_CP$object *, jint) _JC_JCNI_ATTR;
extern void _jc_jas_LocalVarEntry$method$_init$300984af1e9ff307(_jc_env *, struct _jc_jas_LocalVarEntry$object *, struct _jc_jas_Label$object *, struct _jc_jas_Label$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_jas_LocalVarEntry$method$resolve$f7bbca8128967cc2(_jc_env *, struct _jc_jas_LocalVarEntry$object *, struct _jc_jas_ClassEnv$object *) _JC_JCNI_ATTR;
extern void _jc_jas_LocalVarEntry$method$write$d61e8c36d8c1cacd(_jc_env *, struct _jc_jas_LocalVarEntry$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_jas_LocalVarEntry$method_info$resolve$f7bbca8128967cc2;
extern _jc_method _jc_jas_LocalVarEntry$method_info$write$d61e8c36d8c1cacd;

// Virtual methods structure
struct _jc_jas_LocalVarEntry$vmethods {
	void	(*resolve$f7bbca8128967cc2)(_jc_env *, struct _jc_jas_LocalVarEntry$object *, struct _jc_jas_ClassEnv$object *) _JC_JCNI_ATTR;
	void	(*write$d61e8c36d8c1cacd)(_jc_env *, struct _jc_jas_LocalVarEntry$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_jas_LocalVarEntry$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_LocalVarEntry$vmethods	jas_LocalVarEntry;
};

// Vtype
struct _jc_jas_LocalVarEntry$vtype {
	_jc_type			type;
	_jc_jas_LocalVarEntry$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_LocalVarEntry$sub_refs {
	struct _jc_jas_Label$object	*start;
	struct _jc_jas_Label$object	*end;
	struct _jc_jas_CP$object	*name;
	struct _jc_jas_CP$object	*sig;
};

// Reference instance fields (object)
struct _jc_jas_LocalVarEntry$refs {
    _jc_jas_LocalVarEntry$sub_refs	jas_LocalVarEntry;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_LocalVarEntry$sub_nonrefs {
	jint	slot;
};

// Non-reference instance fields (object)
struct _jc_jas_LocalVarEntry$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_LocalVarEntry$sub_nonrefs	jas_LocalVarEntry;
};

// Object instance structure
struct _jc_jas_LocalVarEntry$object {
	_jc_jas_LocalVarEntry$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_LocalVarEntry$vtype	*vtype;
	_jc_jas_LocalVarEntry$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_LocalVarEntry$vtype _jc_jas_LocalVarEntry$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_LocalVarEntry, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_LocalVarEntry$class_object;

#endif	/* _JC_jas_LocalVarEntry_H_ */
